@@ -1,13 +1,11 @@
 package Getopt::Long::EvenLess;
 
-our $DATE = '2015-06-19'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-10-29'; # DATE
+our $VERSION = '0.05'; # VERSION
 
-use 5.010001;
-use strict 'subs', 'vars';
-# IFUNBUILT
-# use warnings;
-# END IFUNBUILT
+# let's be minimalistic
+#use strict 'subs', 'vars';
+#use warnings;
 
 our @EXPORT   = qw(GetOptions);
 our @EXPORT_OK = qw(GetOptionsFromArray);
@@ -190,21 +188,22 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.04 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2015-06-19.
+This document describes version 0.05 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2016-10-29.
 
 =head1 DESCRIPTION
 
 B<EXPERIMENTAL WORK>.
 
-This module is a reimplementation of L<Getopt::Long>, but with much less
-features. It's an even more stripped down version of L<Getopt::Long::less> and
-is perhaps less convenient to use for day-to-day scripting work.
+This module (GLEL for short) is a reimplementation of L<Getopt::Long> (GL for
+short), but with much less features. It's an even more stripped down version of
+L<Getopt::Long::Less> (GLL for short) and is perhaps less convenient to use for
+day-to-day scripting work.
 
 The main goal is minimum amount of code and small startup overhead. This module
 is an experiment of how little code I can use to support the stuffs I usually do
-with Getopt::Long.
+with GL.
 
-Compared to Getopt::Long and Getopt::Long::Less, it:
+Compared to GL and GLL, it:
 
 =over
 
@@ -231,34 +230,41 @@ object as its first argument.
 
 =back
 
-Sample startup overhead benchmark:
+The result?
 
-                            Rate     load_gl      run_gl run_gl_less run_gl_evenless load_gl_evenless load_gl_less   perl
- load_gl            76.8+-0.17/s          --       -0.7%      -50.0%          -64.0%           -67.3%       -69.2% -88.2%
- run_gl             77.3+-0.18/s 0.66+-0.32%          --      -49.6%          -63.8%           -67.1%       -69.0% -88.1%
- run_gl_less        153.5+-3.5/s  99.9+-4.5%  98.6+-4.5%          --          -28.1%           -34.7%       -38.4% -76.3%
- run_gl_evenless      213.5+-2/s   178+-2.7% 176.2+-2.7%  39.1+-3.4%              --            -9.2%       -14.3% -67.1%
- load_gl_evenless   235.2+-1.1/s 206.2+-1.6% 204.2+-1.6%  53.2+-3.5%      10.2+-1.2%               --        -5.6% -63.7%
- load_gl_less     249.14+-0.82/s 224.4+-1.3% 222.3+-1.3%  62.3+-3.7%      16.7+-1.2%      5.94+-0.62%           -- -61.6%
- perl               648.3+-1.9/s   744.2+-3% 738.7+-3.1% 322.4+-9.6%       203.7+-3%      175.7+-1.6%  160.2+-1.1%     --
+B<Amount of code>. GLEL is about 175 lines of code, while GL is about 1500.
+Sure, if you I<really> want to be minimalistic, you can use this single line of
+code to get options:
+
+ @ARGV = grep { /^--([^=]+)(=(.*))?/ ? ($opts{$1} = $2 ? $3 : 1, 0) : 1 } @ARGV;
+
+and you're already able to extract C<--flag> or C<--opt=val> from C<@ARGV> but
+you also lose a lot of stuffs like autoabbreviation, C<--opt val> syntax support
+syntax (which is more common, but requires you specify an option spec), custom
+handler, etc.
+
+B<Startup overhead>. Here's a sample startup overhead benchmark:
+
+                            Rate        run_gl       load_gl   run_gl_less  load_gl_less run_gl_evenless load_gl_evenless   perl
+ run_gl            78.71+-0.21/s            --         -1.0%        -66.6%        -66.9%          -80.3%           -80.9% -87.3%
+ load_gl           79.55+-0.12/s   1.06+-0.31%            --        -66.2%        -66.6%          -80.1%           -80.7% -87.2%
+ run_gl_less      235.68+-0.28/s 199.41+-0.86% 196.28+-0.56%            --         -1.0%          -41.1%           -42.7% -62.1%
+ load_gl_less         238+-0.4/s 202.36+-0.95%  199.2+-0.67%   0.98+-0.21%            --          -40.6%           -42.2% -61.7%
+ run_gl_evenless    400.3+-1.9/s   408.6+-2.8%   403.3+-2.5%  69.87+-0.83%  68.21+-0.85%              --            -2.7% -35.6%
+ load_gl_evenless   411.7+-1.7/s     423+-2.5%   417.5+-2.2%  74.67+-0.73%  72.96+-0.76%     2.82+-0.64%               -- -33.8%
+ perl               621.4+-1.8/s   689.4+-3.1%   681.2+-2.6% 163.66+-0.84% 161.09+-0.89%    55.21+-0.87%     50.95+-0.75%     --
  
  Average times:
-   perl            :     1.5425ms
-   load_gl_less    :     4.0138ms
-   load_gl_evenless:     4.2517ms
-   run_gl_evenless :     4.6838ms
-   run_gl_less     :     6.5147ms
-   run_gl          :    12.9366ms
-   load_gl         :    13.0208ms
+   perl            :     1.6093ms
+   load_gl_evenless:     2.4290ms
+   run_gl_evenless :     2.4981ms
+   load_gl_less    :     4.2017ms
+   run_gl_less     :     4.2430ms
+   load_gl         :    12.5707ms
+   run_gl          :    12.7049ms
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<Getopt::Long>
-
-L<Getopt::Long::Less>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Long-EvenLess>.
@@ -275,13 +281,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Getopt::Long>
+
+L<Getopt::Long::Less>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
